"""
Calculate index for bunkering operations  and plot results
Created: 03. June 2018
Author: Marion Aarsnes
"""

# Import packages
import pandas as pd                 # Read CSV
import numpy as np                  # Scientific computation
import seaborn as sns               # Library of plots built upon matplotlib
import matplotlib.pyplot as plt     # Plots

# Read CSV file
AIS_dataframe = pd.read_csv('filedirectory/filename.csv')
print(AIS_dataframe.columns)

# Clean up dataframe
AIS_dataframe = AIS_dataframe[['Unnamed: 0','imo.b', 'shipType.s', 'length.s', 'bunkeringLength_hrs', 'anchoringLength_hrs', 'BunkUnixStart',
       'BunkUnixEnd', 'AnchorUnixStart', 'AnchorUnixEnd', 'confidence_mean', 'bunkeringType', 'timeBeforeBunkering_hrs', 'timeAfterBunkering_hrs']]
AIS_dataframe = AIS_dataframe.rename(columns={"Unnamed: 0": "OperationNr",
                                              "imo.b": "IMO",
                                              "shipType.s": "ShipType",
                                              "length.s": "ShipLength",
                                              "anchoringLength_hrs": "AnchoringLengthHrs",
                                              "bunkeringLength_hrs": "BunkeringLengthHrs",
                                              "confidence_mean": "ConfMean",
                                              "bunkeringType": "BunkeringType",
                                              "timeBeforeBunkering_hrs": "WTime",
                                              "timeAfterBunkering_hrs": "PBTime"})

AIS_dataframe = AIS_dataframe.fillna(value="nan")[AIS_dataframe.ShipType != "nan"]

# Set plot style
sns.set(style="whitegrid", color_codes=True)

print(AIS_dataframe.head(4))
print(AIS_dataframe.ShipLength[4])
print(AIS_dataframe.ShipLength[0])

# Number of operations to be calculated for
num = len(AIS_dataframe.ShipLength)    # Replace 20 with len(AIS_dataframe.ShipLength) to calculate index for all operations

# Create empty matrix to store index data
index_list = np.zeros(shape=(num,6))
index_list_berth = []
index_list_anchor = []

# Define quantiles
WTquant_0 = 2       # Maximum accepted WT
WTquant_75 = 5.55
PBTquant_0 = 2      # Minimum accepted PBT
PBTquant_75 = 10.58

# Calculate index
# Array = [Operation nr, Waiting Time, Post Bunkering Time, Score WT, score PBT, index]
def calc_index():
    for i in range(0,num):
        index_list[i,0] = int(i+1) #int(AIS_dataframe.OperationNr[i])
        index_list[i,1] = AIS_dataframe.WTime[i]
        index_list[i,2] = AIS_dataframe.PBTime[i]
        if AIS_dataframe.WTime[i] <= WTquant_0:
            TWT = 1
        elif AIS_dataframe.WTime[i] > WTquant_0 and AIS_dataframe.WTime[i] < WTquant_75:
            TWT = (111/71) - ((20*AIS_dataframe.WTime[i])/71)
        else:
            TWT = 0
        if AIS_dataframe.PBTime[i] <= PBTquant_0:
            TPBT = 0
        elif AIS_dataframe.PBTime[i] > PBTquant_0 and AIS_dataframe.PBTime[i] < PBTquant_75:
            TPBT = (-105/424) + ((50*AIS_dataframe.PBTime[i])/424)
        else:
            TPBT = 1
        index_list[i,3] = TWT
        index_list[i,4] = TPBT
        index_list[i,5] = TWT + ((1-TWT)*TPBT)
        if str(AIS_dataframe.BunkeringType[i]) == "Anchorage" and AIS_dataframe.ConfMean[i] >= 0.7:
            index_list_anchor.append(TWT + ((1-TWT)*TPBT))
        elif str(AIS_dataframe.BunkeringType[i]) == "Berth" and AIS_dataframe.ConfMean[i] >= 0.7:
            index_list_berth.append(TWT + ((1 - TWT) * TPBT))
    return index_list, index_list_anchor, index_list_berth

index_list, index_list_anchor, index_list_berth = calc_index()

print(index_list)

# Print array of calculate indexes to .txt-file
np.savetxt('maximums.txt', index_list)

# Plot histogram with Kernel Density Line
ax = sns.distplot(index_list_berth,
                bins=50, color='r', hist_kws=dict(edgecolor="r", linewidth=1), label='At berth')
ax = sns.distplot(index_list_anchor,
                bins=50, color= 'b', hist_kws=dict(edgecolor="b", linewidth=1), label='At anchorage')
ax.set(ylabel="Density", xlabel="QBT")
plt.xlim(0,1.05)
plt.legend()
plt.show()


# Normalised plot

# Berth
# Sort list by increasing QBT
index_list_berth.sort()

# Create normalising column
def fill_value_b():
    norm_b = []
    for i in range(len(index_list_berth)):
        norm_b.append((i+1)/len(index_list_berth)*100)
    return norm_b

norm_b = fill_value_b()

# Anchorage
# Sort list by increasing QBT
index_list_anchor.sort()

# Create normalising column
def fill_value_a():
    norm_a = []
    for i in range(len(index_list_anchor)):
        norm_a.append((i+1)/len(index_list_anchor)*100)
    return norm_a

norm_a = fill_value_a()

# Plot normalised QBT for anchorage and berth operations
plt.plot(index_list_anchor, norm_a, color='b', label='At anchorage')
plt.plot(index_list_berth, norm_b, color='r', label='At berth')
plt.title('QBT normalised over number of operations')
plt.xlabel("QBT")
plt.ylabel("Percentage")
plt.legend()
plt.xlim(0,1.05)
plt.show()