"""
Plot histogram and normalised distribution of Confidence Mean (certainty measure)
Created: 29.april 2018
Author: Marion Aarsnes
"""

import pandas as pd                 # Data analysis tools
import seaborn as sns               # Library of plots built upon matplotlib
import matplotlib.pyplot as plt     # Plots
import matplotlib.ticker as mtick   # Formatting plots
import numpy as np                  # Scientific computation

# Read CSV file
AIS_dataframe = pd.read_csv('filedirectory/filename.csv')
print(AIS_dataframe.columns)

# Clean up dataframe
AIS_dataframe = AIS_dataframe[['imo.b', 'shipType.s', 'length.s', 'bunkeringLength_hrs', 'anchoringLength_hrs', 'confidence_mean']]
AIS_dataframe = AIS_dataframe.rename(columns={"imo.b": "IMO",
                                              "shipType.s": "ShipType",
                                              "length.s": "ShipLength",
                                              "anchoringLength_hrs": "AnchoringLengthHrs",
                                              "bunkeringLength_hrs": "BunkeringLengthHrs",
                                              "confidence_mean": "ConfMean"})

AIS_dataframe = AIS_dataframe.fillna(value="nan")[AIS_dataframe.ShipType != "nan"]

# Set plot variables
sns.set(style="whitegrid", color_codes=True)
sns.despine(left=True)

# Plot histogram of Confidence Mean from initial algorithm output
ax = sns.distplot(AIS_dataframe.ConfMean,
                  bins=25, kde=False, hist_kws=dict(edgecolor='b', linewidth=2))
ax.set(ylabel="Number of operations", xlabel="Confidence mean", title="Distribution of Confidence Mean")
plt.legend()
plt.show()

# Plot histogram of Confidence Mean >= 0.7

# Remove rows with Confidence Mean < 0.7 from dataframe
AIS_dataframe = AIS_dataframe[AIS_dataframe.ConfMean >= 0.7]

# Plot certainty measure
ax = sns.distplot(AIS_dataframe.ConfMean,
                  bins=25, kde=False, hist_kws=dict(edgecolor='b', linewidth=2))
ax.set(ylabel="Number of operations", xlabel="Confidence mean", title="Distribution of Confidence Mean")
plt.legend()
plt.show()


