"""
Create normalised plots
Created: 02. May 2018
Author: Marion Aarsnes
"""

import pandas as pd                 # Read CSV
import seaborn as sns               # Library of plots built upon matplotlib
import matplotlib.pyplot as plt     # Plots
import matplotlib.ticker as mtick   # Formatting plots

# Read CSV file
AIS_dataframe = pd.read_csv('filedirecotry/filename.csv')
print(AIS_dataframe.columns)

# Clean up dataframe
AIS_dataframe = AIS_dataframe[['imo.b', 'length.b', 'shipType.s', 'length.s', 'bunkeringLength_hrs', 'anchoringLength_hrs', 'confidence_mean', "bunkeringType"]] #, 'confidence_mean']
AIS_dataframe = AIS_dataframe.rename(columns={"imo.b": "IMO",
                                              "shipType.s": "ShipType",
                                              "length.b": "BargeLength",
                                              "length.s": "ShipLength",
                                              "anchoringLength_hrs": "AnchoringLengthHrs",
                                              "bunkeringLength_hrs": "BunkeringLengthHrs",
                                              "bunkeringType": "BunkeringType",
                                              "confidence_mean": "ConfMean"})

AIS_dataframe = AIS_dataframe.fillna(value="nan")[AIS_dataframe.ShipType != "nan"]
# Removing rows with Confidence Mean < 0.7
AIS_dataframe = AIS_dataframe[AIS_dataframe.ConfMean >= 0.7]


# Reducing dataframe to shiptypes with minimum 100 registrations
AIS_dataframe = AIS_dataframe.query("ShipType in ('Bulk Carrier','Container Ship','Crude Oil Tanker','Chemical/Oil Products Tanker',"
                                    "'Vehicles Carrier','LPG Tanker','General Cargo Ship','Oil Products Tanker',"
                                    "'Ore Carrier','LNG Tanker',)")

# Set plotting style
sns.set(style="whitegrid", color_codes=True)

# Create new column with normalised values
def fill_value_conf():
    norm = []
    for i in range(len(AIS_dataframe.ConfMean)):
        norm.append((i+1)/len(AIS_dataframe.ConfMean)*100)
    return norm

norm = fill_value_conf()

# ------------------ Normalised certainty---------------------

AIS_dataframe_conf = AIS_dataframe

# Sort by increasing certainty
AIS_dataframe_conf = AIS_dataframe_conf.sort_values('ConfMean')

# Append normalised column
AIS_dataframe_conf['norm'] = norm

# Plot
plt.plot(AIS_dataframe_conf.ConfMean, AIS_dataframe_conf.norm)
plt.title('Confidence Mean normalised over number of operations')
plt.xlabel("Confidence Mean")
plt.ylabel("Percentage")
plt.show()

# ------------------ Normalised barge lengths ---------------------

AIS_dataframe_blen = AIS_dataframe

# Sort by increasing certainty
AIS_dataframe_blen = AIS_dataframe_blen.sort_values('BargeLength')

# Append new column to dataframe
AIS_dataframe_blen['norm'] = norm
print(max(AIS_dataframe_blen.BargeLength))

# Plot
plt.plot(AIS_dataframe_blen.BargeLength, AIS_dataframe_blen.norm)
plt.title('Barge Length normalised over number of operations')
plt.xlabel("Barge Length [meters]")
plt.ylabel("Percentage of operations")
plt.xlim(0,130)
plt.show()

# ------------------ Normalised ship lengths ---------------------

AIS_dataframe_slen = AIS_dataframe

# Sort by increasing certainty
AIS_dataframe_slen = AIS_dataframe_slen.sort_values('ShipLength')

# Append new column to dataframe
AIS_dataframe_slen['norm'] = norm
print(max(AIS_dataframe_slen.ShipLength))

# Plot
plt.plot(AIS_dataframe_slen.ShipLength, AIS_dataframe_slen.norm)
plt.title('Ship Length normalised over number of operations')
plt.xlabel("Ship Length [meters]")
plt.ylabel("Percentage")
plt.show()

# -------------------- Normalised lay time ------------------------

# Create new dataframes for bunkering type
# Anchorage
AIS_dataframe_anchor = AIS_dataframe[AIS_dataframe.BunkeringType == 'Anchorage']
# Berth
AIS_dataframe_berth = AIS_dataframe[AIS_dataframe.BunkeringType == 'Berth']

# -------------------- Normalised time at anchorage ------------------------

AIS_dataframe_anchor_len = AIS_dataframe_anchor

# Sort by increasing certainty
AIS_dataframe_anchor_len = AIS_dataframe_anchor_len.sort_values('AnchoringLengthHrs')

# Create new column with normalised values
def fill_value_anch():
    norm_anch = []
    for i in range(len(AIS_dataframe_anchor)):
        norm_anch.append((i+1)/len(AIS_dataframe_anchor.ConfMean)*100)
    return norm_anch

norm_anch = fill_value_anch()

# Append new column to dataframe
AIS_dataframe_anchor_len['norm'] = norm_anch

# Plot
plt.plot(AIS_dataframe_anchor_len.AnchoringLengthHrs, AIS_dataframe_anchor_len.norm)
plt.title('Anchoring time normalised over number of operations')
plt.xlabel("Anchoring time [hours]")
plt.ylabel("Percentage")
plt.show()

# ------------------ Normalised time at berth ---------------------

AIS_dataframe_berth_len = AIS_dataframe_berth

# Sort by increasing certainty
AIS_dataframe_berth_len = AIS_dataframe_berth_len.sort_values('AnchoringLengthHrs')

# Create new column with normalised values
def fill_value_berth():
    norm_berth = []
    for i in range(len(AIS_dataframe_berth)):
        norm_berth.append((i+1)/len(AIS_dataframe_berth.ConfMean)*100)
    return norm_berth

norm_berth = fill_value_berth()

# Append new column to dataframe
AIS_dataframe_berth_len['norm'] = norm_berth

# Plot
plt.plot(AIS_dataframe_berth_len.AnchoringLengthHrs, AIS_dataframe_berth_len.norm)
plt.title('Berth time normalised over number of operations')
plt.xlabel("Anchoring time [hours]")
plt.ylabel("Percentage")
plt.show()


# ------------------ Normalised bunkering time ---------------------

# All operations
# Create new dataframe and sort by increasing certainty
AIS_dataframe_bunk_all= AIS_dataframe.sort_values('BunkeringLengthHrs')
# Add new column to dataframe
AIS_dataframe_bunk_all['norm'] = norm

# Plot
plt.plot(AIS_dataframe_bunk_all.BunkeringLengthHrs, AIS_dataframe_bunk_all.norm)
plt.title('Bunkering time normalised over number of operations')
plt.xlabel("Bunkering Time [hours]")
plt.ylabel("Percentage")
plt.xlim(0,35)
plt.show()


# Anchorage
# Create new dataframe
AIS_dataframe_bunk_anchor = AIS_dataframe[AIS_dataframe.BunkeringType == 'Anchorage']
# Sort by increasing certainty
AIS_dataframe_bunk_anchor = AIS_dataframe_bunk_anchor.sort_values('BunkeringLengthHrs')
# Add new column to dataframe
AIS_dataframe_bunk_anchor['norm'] = norm_anch

# Plot
plt.plot(AIS_dataframe_bunk_anchor.BunkeringLengthHrs, AIS_dataframe_bunk_anchor.norm)
plt.title('Bunkering time at anchorage normalised over number of operations')
plt.xlabel("Bunkering Time [hours]")
plt.ylabel("Percentage")
plt.xlim(0,35)
plt.show()

# Berth
# Create new dataframe
AIS_dataframe_bunk_berth = AIS_dataframe[AIS_dataframe.BunkeringType == 'Berth']
# Sort by increasing certainty
AIS_dataframe_bunk_berth = AIS_dataframe_bunk_berth.sort_values('BunkeringLengthHrs')
# Add new column to dataframe
AIS_dataframe_bunk_berth['norm'] = norm_berth

# Plot
plt.plot(AIS_dataframe_bunk_berth.BunkeringLengthHrs, AIS_dataframe_bunk_berth.norm)
plt.title('Bunkering time at berth normalised over number of operations')
plt.xlabel("Bunkering Time [hours]")
plt.ylabel("Percentage")
plt.xlim(0,35)
plt.show()


# ------------------- Bunkering time less than 24 hours -------------------

# Create new dataframe for operations with bunkering of less than 24 hours
AIS_dataframe_24 = AIS_dataframe[AIS_dataframe.BunkeringLengthHrs <= 24]

# Sort dataframe by increasing bunkering time
AIS_dataframe_bunk_all_24= AIS_dataframe_24.sort_values('BunkeringLengthHrs')

# Create new column with normalised values
def fill_value_all_24():
    norm_24 = []
    for i in range(len(AIS_dataframe_bunk_all_24)):
        norm_24.append((i+1)/len(AIS_dataframe_bunk_all_24.ConfMean)*100)
    return norm_24

norm_24 = fill_value_all_24()

# Append new column to dataframe
AIS_dataframe_bunk_all_24['norm'] = norm_24

# Plot normalised plot for all operations
plt.plot(AIS_dataframe_bunk_all_24.BunkeringLengthHrs, AIS_dataframe_bunk_all_24.norm)
plt.title('Bunkering time normalised over number of operations')
plt.xlabel("Bunkering Time [hours]")
plt.ylabel("Percentage")
plt.xlim(0,27)
plt.show()


# At anchorage
# Create new dataframe and sort by increasing bunkering time
AIS_dataframe_bunk_all_24a = AIS_dataframe_24[AIS_dataframe_24.BunkeringType == 'Anchorage']
AIS_dataframe_bunk_all_24a = AIS_dataframe_bunk_all_24a.sort_values('BunkeringLengthHrs')

# Create new column with normalised values
def fill_value_all_24a():
    norm_24a = []
    for i in range(len(AIS_dataframe_bunk_all_24a)):
        norm_24a.append((i+1)/len(AIS_dataframe_bunk_all_24a.ConfMean)*100)
    return norm_24a

norm_24a = fill_value_all_24a()

# Append new column to dataframe
AIS_dataframe_bunk_all_24a['norm'] = norm_24a

# Plot normalised plot for bunkering at anchorage
plt.plot(AIS_dataframe_bunk_all_24a.BunkeringLengthHrs, AIS_dataframe_bunk_all_24a.norm)
plt.title('Bunkering time normalised over number of operations')
plt.xlabel("Bunkering Time at anchorage [hours]")
plt.ylabel("Percentage")
plt.xlim(0,27)
plt.show()

# At berth
# Create new dataframe and sort by increasing bunkering time
AIS_dataframe_bunk_all_24b = AIS_dataframe_24[AIS_dataframe_24.BunkeringType == 'Berth']
AIS_dataframe_bunk_all_24b = AIS_dataframe_bunk_all_24b.sort_values('BunkeringLengthHrs')

# Create new column with normalised values
def fill_value_all_24b():
    norm_24b = []
    for i in range(len(AIS_dataframe_bunk_all_24b)):
        norm_24b.append((i+1)/len(AIS_dataframe_bunk_all_24b.ConfMean)*100)
    return norm_24b

norm_24b = fill_value_all_24b()

# Append new column to dataframe
AIS_dataframe_bunk_all_24b['norm'] = norm_24b

# Plot normalised plot of bunkerings at berth
plt.plot(AIS_dataframe_bunk_all_24b.BunkeringLengthHrs, AIS_dataframe_bunk_all_24b.norm)
plt.title('Bunkering time normalised over number of operations')
plt.xlabel("Bunkering Time at berth [hours]")
plt.ylabel("Percentage")
plt.xlim(0,27)
plt.show()


# Plot anch and berth
plt.plot(AIS_dataframe_bunk_all_24b.BunkeringLengthHrs, AIS_dataframe_bunk_all_24b.norm, label='At berth')
plt.plot(AIS_dataframe_bunk_all_24a.BunkeringLengthHrs, AIS_dataframe_bunk_all_24a.norm, '--', color='grey', label='At anchorage')
plt.title('Bunkering time normalised over number of operations')
plt.xlabel("Bunkering Time at berth [hours]")
plt.ylabel("Percentage")
plt.xlim(0,27)
plt.legend()
plt.show()