"""
Print various data from dataframe
Created: 29. March 2018
Author: Marion Aarsnes
"""

import pandas as pd                 # Read CSV
import seaborn as sns               # Library of plots built upon matplotlib
import matplotlib.pyplot as plt     # Plots

# Read CSV file
AIS_dataframe = pd.read_csv('filedirectory/filename.csv')
print(AIS_dataframe.columns)
# Num lines: 19 901

# Clean up dataframe
AIS_dataframe = AIS_dataframe[['imo.b', 'shipType.b', 'length.b', 'shipType.s', 'length.s', 'bunkeringLength_hrs', 'anchoringLength_hrs', 'bunkeringType', 'confidence_mean', 'timeBeforeBunkering_hrs', 'timeAfterBunkering_hrs']]
AIS_dataframe = AIS_dataframe.rename(columns={"imo.b": "IMO",
                                              "shipType.b": "BargeType",
                                              "length.b": "BargeLength",
                                              "shipType.s": "ShipType",
                                              "length.s": "ShipLength",
                                              "anchoringLength_hrs": "AnchoringLengthHrs",
                                              "bunkeringLength_hrs": "BunkeringLengthHrs",
                                              "bunkeringType": "BunkeringType",
                                              "confidence_mean": "ConfMean",
                                              "timeBeforeBunkering_hrs": "WaitingTime",
                                              "timeAfterBunkering_hrs": "PBTime"})

AIS_dataframe = AIS_dataframe.fillna(value="nan")[AIS_dataframe.ShipType != "nan"]
# Require a minimum confidence mean of 0.7
AIS_dataframe = AIS_dataframe[AIS_dataframe.ConfMean >= 0.7]

# Reduce dataframe to shiptypes with minimum 100 registrations
AIS_dataframe = AIS_dataframe.query("ShipType in ('Bulk Carrier','Container Ship','Crude Oil Tanker','Chemical/Oil Products Tanker',"
                                    "'Vehicles Carrier','LPG Tanker','General Cargo Ship','Oil Products Tanker',"
                                    "'Ore Carrier','LNG Tanker',)")

# Creae new dataframes for bunkering type
# Anchorage
AIS_dataframe_anchor = AIS_dataframe[AIS_dataframe.BunkeringType == 'Anchorage']
print('Length of dataframe anchorage')
# Berth
AIS_dataframe_berth = AIS_dataframe[AIS_dataframe.BunkeringType == 'Berth']

# --------------------------------- Printing data --------------------------------
# .describe()) - print general data
# .count() - count number of registrations

# -------------------------------- All operations --------------------------------
# Ship length
print('Ship length')
print(AIS_dataframe['ShipLength'].describe())

# Print length of dataframe
print('Length of dataframe')
print(len(AIS_dataframe.IMO))

# -------------------------------- At anchorage --------------------------------
print('Length of dataframe anchorage')
print(len(AIS_dataframe_anchor.ShipLength))

print('Anchorage length')
print(AIS_dataframe['AnchoringLengthHrs'].describe())
print(AIS_dataframe['AnchoringLengthHrs'].count())

print('Anchorage time')
print(AIS_dataframe_anchor['AnchoringLengthHrs'].describe())
print(AIS_dataframe_anchor['AnchoringLengthHrs'].count())

print('Bunkering time at anchorage')
print(AIS_dataframe_anchor['BunkeringLengthHrs'].describe())
print(AIS_dataframe_anchor['BunkeringLengthHrs'].count())

# -------------------------------- At berth --------------------------------
print('Length of dataframe berth')
print(len(AIS_dataframe_berth.IMO))

print('Data for Bunkering')
print(AIS_dataframe['BunkeringLengthHrs'].describe())
print(AIS_dataframe['BunkeringLengthHrs'].count())

print('Berth time')
print(AIS_dataframe_berth['AnchoringLengthHrs'].describe())
print(AIS_dataframe_berth['AnchoringLengthHrs'].count())

print('Bunkering time at berth')
print(AIS_dataframe_berth['BunkeringLengthHrs'].describe())
print(AIS_dataframe_berth['BunkeringLengthHrs'].count())

# -------------------------------- Bunker barges --------------------------------
print('Number of unique IMO numbers registered to barges')
print(len(AIS_dataframe['IMO'].unique()))
print('Barge types')
print(AIS_dataframe['BargeType'].unique())
print('Number of unique barge types')
print(len(AIS_dataframe['BargeType'].unique()))
print(AIS_dataframe.BargeLength.describe())

# -------------------------------- Shiptypes --------------------------------
# Loop through each ship type and print data

# Shiptype
for shiptype in AIS_dataframe['ShipType'].unique():
    print(shiptype)
    print(AIS_dataframe[AIS_dataframe.ShipType == shiptype]['BunkeringLengthHrs'].describe())

# Shiplength
print('shiplength')
for shiptype in AIS_dataframe['ShipType'].unique():
    print(shiptype)
    print(AIS_dataframe[AIS_dataframe.ShipType == shiptype]['ShipLength'].describe())

# Anchorage
print('anchorage')
for shiptype in AIS_dataframe['ShipType'].unique():
    print(shiptype)
    print(AIS_dataframe[AIS_dataframe.ShipType == shiptype]['AnchoringLengthHrs'].describe())

# -------------------------------- Waiting Time and Post Bunkering Time --------------------------------
print('Data for WT and PBT all operations')
print(AIS_dataframe['WaitingTime'].describe())
print(AIS_dataframe['PBTime'].describe())

print('Data for WT and PBT at anchorage')
print(AIS_dataframe_anchor['WaitingTime'].describe())
print(AIS_dataframe_anchor['PBTime'].describe())

print('Data for WT and PBT at berth')
print(AIS_dataframe_berth['WaitingTime'].describe())
print(AIS_dataframe_berth['PBTime'].describe())