"""
Plot histograms and distribution of ship lengths and laying time
Created: 11. April 2018
Author: Marion Aarsnes
"""

import pandas as pd                     # Read CSV
import seaborn as sns                   # Library of plots built upon matplotlib
import matplotlib.pyplot as plt         # Plots
import matplotlib.ticker as mtick       # Formatting plots
import numpy as np                      # Scientific computing
from matplotlib.pyplot import xticks   # Rotate plot

# Read CSV file
AIS_dataframe = pd.read_csv('filedirectory/filename.csv')
print(AIS_dataframe.columns)

# Clean up dataframe
AIS_dataframe = AIS_dataframe[['imo.b', 'shipType.s', 'imo.s', 'length.s', 'length.b', 'bunkeringLength_hrs', 'anchoringLength_hrs', 'bunkeringType', 'confidence_mean']]
AIS_dataframe = AIS_dataframe.rename(columns={"imo.b": "IMO",
                                              "shipType.s": "ShipType",
                                              "imo.s": "IMOship",
                                              "length.s": "ShipLength",
                                              "length.b": "BargeLength",
                                              "anchoringLength_hrs": "AnchoringLengthHrs",
                                              "bunkeringLength_hrs": "BunkeringLengthHrs",
                                              "bunkeringType": "BunkeringType",
                                              "confidence_mean": "ConfMean"})

AIS_dataframe = AIS_dataframe.fillna(value="nan")[AIS_dataframe.ShipType != "nan"]
# Require a minimum confidence mean of 0.7
AIS_dataframe = AIS_dataframe[AIS_dataframe.ConfMean >= 0.7]

# Reduce dataframe to shiptypes with minimum 100 registrations
AIS_dataframe = AIS_dataframe.query("ShipType in ('Bulk Carrier','Container Ship','Crude Oil Tanker','Chemical/Oil Products Tanker',"
                                    "'Vehicles Carrier','LPG Tanker','General Cargo Ship','Oil Products Tanker',"
                                    "'Ore Carrier','LNG Tanker',)")

# Set plot style
sns.set(style="whitegrid", color_codes=True)

# ----------------- Distribution of ship lengths ------------------

# Define number of bins
# Bin size
res_len = 10

# Calculate bin number based on bin size
min_slen = min(AIS_dataframe['ShipLength'])
max_slen = max(AIS_dataframe['ShipLength'])
bsize_slen = int((max_slen-min_slen)/res_len) # bin number must be an integer

# Plot histogram
ax = sns.distplot(AIS_dataframe['ShipLength'],
                      bins=bsize_slen,kde=False, hist_kws=dict(edgecolor="b", linewidth=1))
ax.set(ylabel="Number of registered ship lengths", xlabel="Ship length")
plt.xlim(0,450)
plt.legend()
plt.show()

# Plot histogram with Kernel Density Line
ax = sns.distplot(AIS_dataframe['ShipLength'],
                  bins=bsize_slen, hist_kws=dict(edgecolor="b", linewidth=1))
ax.set(ylabel="Density", xlabel="Ship length")
plt.xlim(0,450)
plt.legend()
plt.show()
